@@ -1,13 +1,7 @@
-# -*- coding: utf-8 -*-
 #
 #  This file is part of Sequana software
 #
-#  Copyright (c) 2016 - Sequana Development Team
-#
-#  File author(s):
-#      Thomas Cokelaer <thomas.cokelaer@pasteur.fr>
-#      Dimitri Desvillechabrol <dimitri.desvillechabrol@pasteur.fr>,
-#          <d.desvillechabrol@gmail.com>
+#  Copyright (c) 2016-2022 - Sequana Development Team
 #
 #  Distributed under the terms of the 3-clause BSD license.
 #  The full license is in the LICENSE file, distributed with this software.
@@ -21,6 +15,7 @@ import re
 import ast
 import os
 import sys
+import random
 
 from sequana import mixture
 
@@ -421,66 +416,6 @@ class GenomeCov(object):
             self.chrom_names = tokeep
         self._set_chr_list()
 
-    """
-    def _read_csv(self, input_filename):
-        # set regex to get important information about previous analysis
-        re_threshold = re.compile(r"thresholds:([\d,\.-]+)")
-        re_window_size = re.compile(r"\swindow_size:(\d+)")
-        re_circular = re.compile(r"circular:(\w+)")
-        re_gc_window_size = re.compile(r"gc_window_size:(\d+)")
-        re_genbank = re.compile(r"genbank:([\{0}\w\.\-]+)".format(os.sep))
-        re_chrom = re.compile(r"^# ([\w\-\.]+):")
-        re_gaussian = re.compile(r"(\[\{.+\}\])")
-
-        with open(input_filename, "r") as fp:
-            line = fp.readline()
-            # check if file was generated by sequana_coverage
-            if not line.startswith("# sequana_coverage"):
-                return None
-            # get thresholds
-            thresholds = re_threshold.findall(line)[0]
-            thresholds = [float(f) for f in thresholds.split(',')]
-            self.thresholds = DoubleThresholds(*thresholds)
-
-            # get window size
-            self.window_size = int(re_window_size.search(line).group(1))
-            # get circular
-            circular = re_circular.search(line).group(1)
-            self.circular = False if circular == "False" else True
-            # get gc_window_size
-            gc = re_gc_window_size.search(line)
-            if gc:
-                self.gc_window_size = int(gc.group(1))
-            # get genbank
-            gb = re_genbank.search(line)
-            if gb and not self.genbank_filename:
-                self.genbank_filename = gb.group(1)
-            # get gaussians for each chromosome
-            gaussians_dict = dict()
-            for line in fp:
-                chrom = re_chrom.search(line)
-                if chrom:
-                    gaussians = re_gaussian.search(line)
-                    gaussians = ast.literal_eval(gaussians.group(1))
-                    gaussians_dict[chrom.group(1)] = gaussians
-                else:
-                    break
-            df = pd.read_csv(fp, header=None, names=line.strip().split(","))
-        self.chrom_names = list(df['chr'].drop_duplicates().values)
-        self._set_chr_list()
-
-        # Add gaussians and range informations
-        for chrom in self.chr_list:
-            chrom.set_gaussians(gaussians_dict[chrom.chrom_name])
-            if self.circular:
-                chrom.range = [None, None]
-            else:
-                mid = int(self.window_size/2)
-                chrom.range = [mid, -mid]
-            chrom.mixture_fitting = mixture.EM(
-                chrom.df['scale'][chrom.range[0]:chrom.range[1]])
-    """
-
     def _set_chr_list(self):
         self.chr_list = []
         for name in self.chrom_names:
@@ -1066,7 +1001,7 @@ class ChromosomeCov(object):
         data = data.replace(0, np.nan)
         data = data.dropna()
 
-        if data.empty:
+        if data.empty: #pragma: no cover
             self._df["scale"] = np.ones(len(self.df), dtype=int)
             self._df["zscore"] = np.zeros(len(self.df), dtype=int)
             # define arbitrary values
@@ -1077,7 +1012,6 @@ class ChromosomeCov(object):
 
         # if len data > 100,000 select 100,000 data points randomly
         if len(data) > 100000:
-            import random
 
             indices = random.sample(range(len(data)), 100000)
             data = [data.iloc[i] for i in indices]
@@ -1162,7 +1096,7 @@ class ChromosomeCov(object):
 
         try:
             filtered = self.get_rois()
-        except Exception as err:
+        except Exception as err: #pragma: no cover
             raise (err)
         finally:
             # restore the original threshold
@@ -1230,7 +1164,7 @@ class ChromosomeCov(object):
                     return FilteredGenomeCov(data, self.thresholds, features[self.chrom_name], step=self.binning)
             else:
                 return FilteredGenomeCov(data, self.thresholds, step=self.binning)
-        except KeyError:
+        except KeyError: #pragma: no cover
             logger.error(
                 "Column zscore is missing in data frame.\n"
                 "You must run compute_zscore before get low coverage."
@@ -1332,7 +1266,7 @@ class ChromosomeCov(object):
         if len(df) > 1000000 and sample is True:
             logger.info("sub sample data for plotting the coverage")
             NN = int(len(df) / 1000000)
-        else:
+        else: #pragma: no cover
             NN = 1
 
         # the main coverage plot
@@ -1367,7 +1301,7 @@ class ChromosomeCov(object):
             m4 = high_zcov[high_zcov > 0]
             if len(m4) == 0:
                 m4 = 3
-            else:
+            else: 
                 m4 = m4.max(skipna=True)
             # ignore values equal to zero to compute mean average
             m3 = df[df["cov"] > 0]["cov"].mean()
@@ -1378,7 +1312,7 @@ class ChromosomeCov(object):
 
         try:
             pylab.tight_layout()
-        except:
+        except: #pragma: no cover
             pass
 
         if filename:
@@ -1401,7 +1335,7 @@ class ChromosomeCov(object):
         pylab.xlabel("Z-score", fontsize=fontsize)
         try:
             pylab.tight_layout()
-        except:
+        except: #pragma: no cover
             pass
         pylab.xlim([-max_z, max_z])
         if filename:
@@ -1418,7 +1352,7 @@ class ChromosomeCov(object):
         try:
             self.mixture_fitting.data = d
             self.mixture_fitting.plot(self.gaussians_params, bins=bins, Xmin=0, Xmax=max_z)
-        except ZeroDivisionError:
+        except ZeroDivisionError: #pragma: no cover
             return
 
         pylab.grid(True)
@@ -1427,7 +1361,7 @@ class ChromosomeCov(object):
 
         try:
             pylab.tight_layout()
-        except:
+        except: #pragma: no cover
             pass
         if filename:
             pylab.savefig(filename)
@@ -1507,7 +1441,7 @@ class ChromosomeCov(object):
                 if os.path.isdir(directory):
                     pass
                 else:
-                    msg = "{0} exist and it is not a directory".format(directory)
+                    msg = f"{directory} exist and it is not a directory"
                     logger.error(msg)
                     raise FileExistsError
         return self.df.loc[start:stop].to_csv(filename, **kwargs)
@@ -1557,7 +1491,7 @@ class ChromosomeCov(object):
                     cmap=cmap,
                     **kwargs
                 )
-            except:
+            except: #pragma: no cover
                 h2.plot(
                     bins=bins,
                     xlabel="Per-base coverage",
@@ -1573,8 +1507,9 @@ class ChromosomeCov(object):
         pylab.ylim([ymin, ymax])
         try:
             pylab.tight_layout()
-        except:
+        except: #pragma: no cover
             pass
+
         if filename:
             pylab.savefig(filename)
 
@@ -1631,13 +1566,12 @@ class ChromosomeCov(object):
             bins = pylab.arange(m, M, step)
 
         try:
-            # Y, X, _ = pylab.hist(data, bins=bins, normed=True)
             (
                 Y,
                 X,
             ) = np.histogram(data, bins=bins, density=True)
             return {"X": list(X[1:]), "Y": list(Y)}
-        except:
+        except: #pragma: no cover
             return {"X": [], "Y": []}
 
     def get_summary(self, C3=None, C4=None, stats=None, caller="sequana.bedtools"):
@@ -1717,8 +1651,6 @@ class ChromosomeCov(object):
         # GC content
         if "gc" in self.df.columns:
             stats["GC"] = self.df["gc"].mean() * 100
-            # names.append('GC')
-            # descriptions.append("GC content in %")
 
         return stats
 
@@ -1875,7 +1807,7 @@ class FilteredGenomeCov(object):
         while feature["type"] in FilteredGenomeCov._feature_not_wanted:
             try:
                 feature = next(iter_feature)
-            except StopIteration:
+            except StopIteration: #pragma: no cover 
                 print(
                     "Features types ({0}) are not present in the annotation"
                     " file. Please change what types you want".format(feature["type"])
@@ -1896,7 +1828,7 @@ class FilteredGenomeCov(object):
                 # put locus_tag in gene field if gene doesn't exist
                 try:
                     feature["gene"]
-                except KeyError:
+                except KeyError: #pragma: no cover
                     try:
                         feature["gene"] = feature["locus_tag"]
                     except:
@@ -1904,7 +1836,7 @@ class FilteredGenomeCov(object):
                 # put note field in product if product doesn't exist
                 try:
                     feature["product"]
-                except KeyError:
+                except KeyError: #pragma: no cover
                     try:
                         feature["product"] = feature["note"]
                     except:
